#' ---
#' title: "Figure 4B1: Alacourt Census"
#' author: "Michael Morse"
#' ---
#'
#+ warning = F, message = F
rm(list = ls())
library(magrittr)
library(dplyr)
library(stringr)
library(readr)
library(ggplot2)
library(scales)

#' # Load Data
#' This anonymized data comes from our census of all court cases that originated in Alabama district court in 2013.
#' It is limited to cases where there is a valid court action and a conviction. 

data <- readRDS("Data_4B1.rds")

#' # Plot

annot <- data %>% count(type)
annot %<>% mutate(n = format(n, big.mark = ","))

caption <- paste0("Note: This box plot displays the total legal financial obligations assessed, comparing cases with at least one felony conviction to cases with at least one misdemeanor conviction and no felony convictions, conditioning on cases in which more than the bail fee of $35 is assessed (n = ", annot$n[1], " for felonies, n = ", annot$n[2], " for misdemeanors). The y-axis is log-scaled.")
caption <- paste0(strwrap(caption, 140), sep="", collapse="\n")

g <-
  data %>%
  ggplot(aes(x = type, y = amount.due)) +
  geom_boxplot(width = 0.5) +
  scale_y_log10(labels = scales::dollar_format(),
                breaks = c(50, 100, 1000, 10000, 100000, 1000000)) +
  labs(y = "LFOs Assessed per Conviction",
       x = "Offense Type",
       title = "Variation in LFOs by Offense Type",
       caption = caption) +
  theme(plot.title = element_text(hjust = 0.5),
        plot.caption=element_text(hjust=0, margin=margin(t=15)),
        panel.background = element_blank(),
        axis.line.x =element_line(color="#2b2b2b", size=0.35),
        axis.line.y =element_line(color="#2b2b2b", size=0.35))

g


