#' ---
#' title: "Replicate Figure 4D1: City of Montgomery"
#' author: "Michael Morse"
#' ---
#+ echo = F, message = F
rm(list = ls())
library(magrittr)
library(dplyr)
library(stringr)
library(purrr)
library(readr)
library(readxl)
library(ggplot2)
library(lubridate)
library(knitr)

#' # Load data
#' This is Montgomery municipal data, for both criminal and traffic offenses in both 2013 and 2015. 
#' Assessed_minus_bail represents the total LFOs assessed minus the bail fee. 
#' Tot_within_XX represents the LFOs paid back with XX days.
#+ message = F
combo <- readRDS("Data_4C4.rds")

#' # Create Table
#+ message = F
tbl <-
  combo %>%
  group_by(year, type) %>%
  summarise(assessed_minus_bail = sum(assessed_minus_bail, na.rm = T),
            n = n(),
            tot_within_30 = sum(tot_within_30, na.rm = T),
            tot_within_90 = sum(tot_within_90, na.rm = T),
            tot_within_180 = sum(tot_within_180, na.rm = T)) %>%
  mutate(payback_within_30 = tot_within_30 / assessed_minus_bail,
         payback_within_90 = tot_within_90 / assessed_minus_bail,
         payback_within_180 = tot_within_180 / assessed_minus_bail) %>%
  select(year, type, n, assessed_minus_bail_fee = assessed_minus_bail, everything())

tbl %>% kable()

